
XEP-0223: Persistent Storage of Private Data via PubSub
=======================================================

.. module:: slixmpp.plugins.xep_0223

.. autoclass:: XEP_0223
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end
